#
# spec file for package flameshot
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flameshot
Version:        12.1.0
Release:        3.5
Summary:        Screenshot software
License:        GPL-3.0-only
Group:          Productivity/Graphics/Other
URL:            https://github.com/flameshot-org/flameshot#flameshot
Source0:        https://github.com/flameshot-org/flameshot/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE flameshot-remove-update-check.patch -- Remove update check
Patch0:         flameshot-remove-update-check.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5
BuildRequires:  pkgconfig(Qt5DBus) >= 5
BuildRequires:  pkgconfig(Qt5Gui) >= 5
BuildRequires:  pkgconfig(Qt5Network) >= 5
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets) >= 5
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150400
BuildRequires:  cmake(KF5GuiAddons) >= 5.89.0
%endif
Requires: libQt5Svg5
Suggests:       %{name}-bash-completion
Suggests:       %{name}-fish-completion
Suggests:       %{name}-zsh-completion

%description
A program to capture screenshots.

Features:

 * Customizable appearance
 * Annotation and drawing tools
 * DBus interface
 * Export to file, web

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (flameshot and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for flameshot's CLI.

%package zsh-completion
Summary:        ZSH completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
zsh shell completions for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%setup -q

%build
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150400
%cmake -DUSE_WAYLAND_CLIPBOARD:BOOL=ON
%else
%cmake
%endif
%cmake_build

%install
%cmake_install
%suse_update_desktop_file -r org.flameshot.Flameshot Utility X-SuSE-DesktopUtility
%fdupes %{buildroot}%{_datadir}/icons/hicolor

%files
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/org.flameshot.Flameshot.desktop
%{_datadir}/dbus-1/interfaces/org.flameshot.Flameshot.xml
%{_datadir}/dbus-1/services/org.flameshot.Flameshot.service
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_datadir}/metainfo/org.flameshot.Flameshot.metainfo.xml
%{_mandir}/man1/%{name}.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_flameshot

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/flameshot.fish

%changelog
* Fri Dec 29 2023 Patrick Poitras <patrick.f.poitras@gmail.com>
- Add runtime dependency from libQt5Svg5. This solves the problem
  of the pictures on the buttons not displaying.
* Tue May 16 2023 Guido Berhoerster <guido+opensuse@berhoerster.name>
- Add flameshot-remove-update-check.patch: Remove update check, updates are
  supplied by the distribution and making a network request has privacy
  implications
* Mon Aug  1 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 12.1.0:
  * Rename Imgur API Key to Imgur Application Client ID.
  * Fix issue about externalWidget launchapp.
  * Fix size not appearing on size tool when started from launcher.
  * Added option to pin menu to close pin.
  * Disable option to launch on start by default.
  * Fix magnify windows.
  * DesktopFileParser only reads .desktop files.
* Wed Jun 22 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to version 12.0.0
  * Created basic layer movement functionality
  * Added a new widget to allow the colorwheel to be more easily customized
  * Added magnifier for more precise selections
  * Incremental markers can now have a point if you drag when placing them
  * Pinned screenshots can now be copied to the clipboard or saved to a file
    if a user right clicks on the pinned image
  * Pinned screenshots can now be zoomed with a pinch gesture
  * Make KDE use Freedesktop portal
  * Pinned images can now be moved partially offscreen on linux
  * Wayland builds now use KF Gui (KDE Framework tools) to fix some issues
  * Full changelog: https://github.com/flameshot-org/flameshot/releases/tag/v12.0.0
- Enable Wayland clipboard for Leap 15.4+ and Tumbleweed
* Fri Jan 21 2022 Paolo Stivanin <info@paolostivanin.com>
- Fix requires for zsh-completion
* Wed Jan 19 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 11.0.0:
  * A config file checker has been implemented. If your config file
    contains error it will prompt to on how to fix them.
  * Some config file semantics changed so when you first run version 11,
    it is likely you need to resolve the config file errors.
  * The on-screen help menu has been clarified and dynamically updates
    the hotkeys based on user defined hotkeys.
  * DBus is no longer required for CLI options.
  * Flameshot can now be run in "one off" mode which means that
    the background systray component is now optional.
  * The CLI has been completely refactored.
  * Optimizations to reduce lag on 8k and 4k screens.
  * KNOWN ISSUE: fractional scaling on linux is still not resolved.
- Full changelog: https://github.com/flameshot-org/flameshot/releases/tag/v11.0.0
* Mon Nov 15 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.10.2
  * Maintenance release to fix annoying wayland related bugs
* Mon Jul 26 2021 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 0.10.1
  * The ability to upload to imgur via a hotkey has been removed.
  - Many users accidentally hit the hotkey and uploaded sensitive data
  - Users could accidentally upload the entire desktop by hitting the
    upload key before a region was selection
  * Fixed segfault when parsing invalid config file
* Fri Jul 16 2021 Avindra Goolcharan <avindra@opensuse.org>
- refetch tarball (changed from source)
- cleanup 0.10.0 release notes
* Thu Jul 15 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.10.0
  * known issue: fractional scaling issues We are working with Qt
    upstream on this issue.
  * known issue: KDE Wayland requires modification to the Desktop file.
  * change: close after capture removed due to lack of maintenance
  * feat: automatically run on xcb. This improves compatibility with
    Wayland, multimonitor setups and copy to clipboard
  * feat: save clipboard as jpeg instead of a png. May reduce
    bandwidth when pasting the image into chat or email clients.
  * feat: global shortcut menu. All actions hotkeys are fully
    customizable.
  * feat: "Symmetric" selections by holding Shift when resizing
  * feat: The rectangle tool will now round the corners of the
    rectangles based on the current thickness.
  * feat: All imgur uploads are now tracked in the "Upload History"
    menu. This makes it much easier to delete of images off imgur
    or find the upload link later.
  * feat: New option for setting a "fixed save path". When this is
    enabled a user will no longer need to set the path for images
    that are saved.
  * fix: Under certain circumstance the circle count could get set to
    the wrong number with large numbers of undo / redo. This has
    been fixed.
* Tue Mar 16 2021 Avindra Goolcharan <avindra@opensuse.org>
- Update description with features and flameshot-org
* Sun Feb 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.0
  Known Issues
  * Fractional scaling issues are not resolved. We are working with
    Qt upstream on this issue.
  * KDE Wayland requires modification to the Desktop file.
  New Features
  * Improved Wayland support on Gnome
    + Behind the scenes we configure flameshot to automatically run
    on xcb. This significantly improves the wayland experience.
    This resolves issues with multimonitor setups and copying to
    the clipboard
  * Ability to run flameshot on Sway
  * New option to allow the the clipboard image to be a jpeg
    instead of a png. This may reduce bandwidth when pasting the
    image into chat or email clients.
  * New global shortcut menu. All actions hotkeys are fully
    customizable.
  * Ability to take "symmetric" selections by holding down the
    Shift key while resizing the selection.
  * The rectangle tool will now round the corners of the rectangles
    based on the current thickness.
  * All imgur uploads are now tracked in the "Upload History" menu.
    This makes it much easier to delete of images off imgur or find
    the upload link later.
  * New option for setting a "fixed save path". When this is
    enabled a user will no longer need to set the path for images
    that are saved.
  Fixes
  * Under certain circumstance the circle count could get set to
    the wrong number with large numbers of undo / redo. This has
    been fixed.
  * Close after capture has been removed. This feature was not well
    implemented and lead to numerous bugs.
* Fri Oct 16 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.5
  * Fixed Icon Regression
* Sun Oct 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.4
  * Renamed assets to match DBUS name for flathub support.
  * Fixed issue where theme was not applied to widgets.
  * Fixed issue where pixelate tool did not properly apply pixel
    size and was not symmetric horizontally and vertically.
  * Fixed visual artifact in pin to desktop in appimage release.
  * Fixed issue where CTRL + S did not save active text in text
    tool.
  * Imgur tool now opens in the center of the screen.
  * Translation Updates
    + Brazilian Portuguese
    + German
    + Korean
    + Basque
* Tue Sep 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to versin 0.8.3
  * Small bug fixes
* Thu Sep 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.1
  * Auto contrast on circle counter
* Tue Sep 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.0
  New Features
  * Fix capture after pressing ctrl + S during textarea input
  * Add translations
  * Allow enter key to copy image to clipboard
  * side panel: Add thickness slider
  * Add support for saving as JPG and BMP files.
  * Allow 45 degree adjustment for some tools
  * Add a basic launcher panel.
  * Add option to auto copy URL after upload
  * Add a circle counter tool.
  * Replace the blur tool with pixelate tool.
  * Convert buildsystem from QMake to CMake.
  Fixes
  * Exit non-zero when aborting with --raw.
  * Enable Pin and Text tool by default.
  * Fix the problem that moving or resizing does not affect
    screenshot.
  * Fix problem with re-enabling disabled tray icon.
  * Fix compilation problem against Qt 5.15.
- Drop not longer needed patches:
  * 0001-Fix-build-with-Qt-5.15.patch
  * 0001-utils-confighandler.cpp-Enable-Pin-and-Text-tool-by-.patch
  * desktop-files.patch
- Introduce zsh-completion subpackage
* Fri Jun  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with Qt 5.15:
  * 0001-Fix-build-with-Qt-5.15.patch
* Mon Mar  9 2020 Martin Hauke <mardnh@gmx.de>
- Supplement against bash-completion, not bash
* Sun Apr  7 2019 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * 0001-utils-confighandler.cpp-Enable-Pin-and-Text-tool-by-.patch
    Enables Pin and Text tool by default.
* Tue Aug 28 2018 aloisio@gmx.com
- Update to version 0.6.0
  Features:
  * Allow systray customization with themes. Use
    "flameshot-tray" as the name of the icon.
  * Unification of the desktop file with actions.
  * Notification when screenshots are saved in the clipboard.
  * Use datetime as default name for pics.
  * Undo/Redo with Ctrl+z and Ctrl+Shift+z.
  * Add "Take Screenshot" option as menu item in the systray.
  * Add Side-Panel (open it with Space).
  * Add autostart to config flags.
  * Add Pin tool.
  * Filename: replace colons with dashes.
  * Add Text tool.
  * Delete Imgur image button after uploading it from the
    preview window.
  * Capture single screen:
    + flameshot screen (capture the screen containing the mouse)
    + flameshot screen -n 1 (capture the first screen).
  * Store settings colors in hexadecimal format.
  Fixes:
  * flameshot full -c shouldn't block the desktop.
  * Now you can overwrite exported configuration with the same
    name as a previous exports.
  * Fix flameshot --raw wait time with delay.
  * Fix negative selection geometry bug.
  * Improved hidpi support with some bugs fixed.
- Refreshed desktop-files.patch
* Sat Feb 24 2018 avindra@opensuse.org
- Bump to 0.5.1
  * Modal widgets doesn't prevent the start of a new capture
  * Better hidpi support
  * Tool buttons now don't go out of the screen
  * Use of native file dialog
  * Configurable opacity of the dark area outside the selection
  * Autostart app as a configuration option
  * Polish, french, georgian, chinese, turkish and rusian
    translations
  * Minor fixes
- rebase desktop-files.patch
* Thu Dec 28 2017 jengelh@inai.de
- Remove filler wording from description.
* Fri Dec 22 2017 avindra@opensuse.org
- Bump to 0.5.0
  * Features
  - Blur tool
  - Bash completion
  - Add --raw flag: prints the raw bytes of the png after the capture
  - Catalan translation
  - Preview draw size on mouse pointer after tool selection
  - App Launcher tool: choose an app to open the capture
  - Configuration import, export and reset
  - Experimental Wayland support (Plasma & Gnome)
  - Debian package configuration
  * Accessibility
  - Capture selection resizable from any edge
  * Fixes
  - App version shown properly
  - cli wont break if you prepend gui, full and config arguments
    with a dash
  - Fix rare crash when creating a selection during a graphical
    capture
- Build cleanup:
  * Remove unneeded service file
  * Use Qt macros for building and installing
  * Remove now unneeded .deskop file handling macros
- Package bash completions
* Sun Sep 17 2017 aavindraa@gmail.com
- Bump to 0.4.2 (hotfix release)
- hotfix: persistent configuration wasn't handled correctly for new
  users, failing to set a "initiated" status flag in the
  configuration. That is used to let the program know if a new
  process of Flameshot is the first launch of the program.
* Thu Aug 17 2017 aavindraa@gmail.com
- 0.4.0 release (https://github.com/lupoDharkael/flameshot/releases/tag/v0.4.0)
- lint .spec file
* Tue Aug 15 2017 aavindraa@gmail.com
- Package for the first time (with v0.3.0)
